@@ -115,7 +115,12 @@ class fMMS_GUI(hildon.Program):
 			else:
 				break
 		self.contacts_dialog.destroy()
-		
+
+	""" forces ui update, kinda... god this is AWESOME """
+	def force_ui_update(self):
+		while gtk.events_pending():
+			gtk.main_iteration(False)
+	
 	def contact_number_chosen(self, button, nrdialog):
 		print button.get_label()
 		nr = button.get_label().replace(" ", "")
@@ -190,11 +195,8 @@ class fMMS_GUI(hildon.Program):
 				print "creating dir", self.config.get_imgdir()
 				os.makedirs(self.config.get_imgdir())
 			
-			### TODO: remove ugly hack
-			bus = dbus.SystemBus()
-			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-			interface.SystemNoteInfoprint ("fMMS: Resizing image")
+			hildon.hildon_banner_show_information(self.window, "", "fMMS: Resizing image, this might take a while...")
+			self.force_ui_update()
 			
 			img = Image.open(filename)
 			print "height", img.size[1]
@@ -225,7 +227,11 @@ class fMMS_GUI(hildon.Program):
 	
 	""" sends the message (no shit?) """
 	def send_mms(self, widget):
-		#hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+		hildon.hildon_gtk_window_set_progress_indicator(self.window, 1)
+		# Disable send-button
+		self.bSend.set_sensitive(False)
+		self.force_ui_update()
+		
 		self.osso_c = osso.Context("fMMS", "0.1.0", False)
 		
 		attachment = self.bAttachment.get_label()
@@ -273,7 +279,7 @@ class fMMS_GUI(hildon.Program):
 			note = osso.SystemNote(self.osso_c)
 			errmsg = "Invalid attachment"
 			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure the file is valid" , 'notice')
-			raise
+			#raise
 		except socket.error, exc:
 			#print type(exc)
 			print exc
@@ -282,11 +288,14 @@ class fMMS_GUI(hildon.Program):
 			note = osso.SystemNote(self.osso_c)
 			errmsg = code + " " + text
 			note.system_note_dialog("Sending failed:\nError: " + errmsg + " \nPlease make sure APN settings are correct" , 'notice')
-			raise
+			#raise
 		except Exception, exc:
 			print type(exc)
 			print exc
-			raise
+			#raise
+		finally:
+			hildon.hildon_gtk_window_set_progress_indicator(self.window, 0)
+			self.bSend.set_sensitive(True)
 			
 		if self.attachmentIsResized == True:
 			print "Removing temporary image..."
