@@ -175,7 +175,7 @@ class PushHandler:
 		try:
 			# TODO: remove hardcoded sleep
 			con = ConnectToAPN(self._apn_nicename)
-			time.sleep(7)
+			time.sleep(6)
 			con.connect()
 			
 			### send the m-notifyresp-ind first
@@ -203,10 +203,13 @@ class PushHandler:
 				#mmsdata = opener.open(location)
 				urllib2.install_opener(opener)
 				
-			headers = {'Profile:' : 'http://mms.frals.se/n900.rdf', 'x-wap-profile' : 'http://mms.frals.se/n900.rdf'}
+			headers = {'x-wap-profile': 'http://mms.frals.se/n900.rdf'}
 			req = urllib2.Request(location, headers=headers)
 			mmsdata = urllib2.urlopen(req)
-			
+			try:
+				print mmsdata.info()
+			except:
+				pass
 			mmsdataall = mmsdata.read()
 			fp = open(dirname + "/message", 'w')
 			fp.write(mmsdataall)
